#!/bin/bash
#
# EeePC Camera toggle
# Andrew Wyatt
# Tool to toggle Camera device on / off

. /etc/default/eeepc-acpi

function eeepc_notify {
/usr/bin/notify-send -i camera-web -t 1500 "EeePC $EEEPC_MODEL" "$1"
}

if [ -e "/sys/devices/platform/eeepc/camera" ]; then
  CAMERA_DEVICE="/sys/devices/platform/eeepc/camera"
  CAMERA_STATUS=$(cat $CAMERA_DEVICE)
fi

if [ ! -d "$EEEPC_VAR" ]; then
  mkdir $EEEPC_VAR 2>/dev/null
fi

if [ -e "$EEEPC_VAR/cam_saved" ]; then
  CAMERA_SAVED=$(cat $EEEPC_VAR/cam_saved)
else
  CAMERA_SAVED=1
fi

function cam_toggle {
  if [ "$CAMERA_STATUS" = "-1" ]; then
    eeepc_notify "Webcam module not installed"
    exit 1
  elif [ "$CAMERA_STATUS" = "0" ]; then
    eeepc_notify "Webcam Enabled"
    /sbin/modprobe uvcvideo
    echo 1 > $EEEPC_VAR/cam_saved
    echo 1 > $CAMERA_DEVICE
  elif [ "$CAMERA_STATUS" = "1" ]; then
    eeepc_notify "Webcam Disabled"
    echo 0 > $EEEPC_VAR/cam_saved
    echo 0 > $CAMERA_DEVICE
    /sbin/modprobe -r uvcvideo 2>/dev/null
  fi
}

function cam_restore {
  if [ "$CAMERA_SAVED" = "1" ]; then
    eeepc_notify "Webcam Enabled"
    /sbin/modprobe uvcvideo
    echo 1 > $CAMERA_DEVICE
  elif [ "$CAMERA_SAVED" = "0" ]; then
    eeepc_notify "Webcam Disabled"
    echo 0 > $CAMERA_DEVICE
    /sbin/modprobe -r uvcvideo 2>/dev/null
  fi
}

case $1 in
  restore)
    cam_restore
  ;;
  *)
    cam_toggle
  ;;
esac
