#!/bin/bash
#
# EeePC LVDS resolution toggle
# Andrew Wyatt
# Tool to toggle LVDS output resolutions

. /etc/default/eeepc-acpi

function eeepc_notify {
/usr/bin/notify-send -i display -t 1500 "EeePC $EEEPC_MODEL" "$1"
}

if [ ! -d "$EEEPC_VAR" ]; then
  mkdir $EEEPC_VAR
fi

if [ -e "/tmp/eee-lvds-temp" ]; then
  rm -f /tmp/eee-lvds-temp 2>/dev/null
fi

LVDS_XRANDR=$(xrandr > /tmp/eee-lvds-temp)
LVDS_MODES=$(cat /tmp/eee-lvds-temp | grep -F -e LVDS -A 12 | grep [0-9]x[0-9] | grep -v -e LVDS | awk '{printf $1" "}')
LVDS_CURRENT=$(cat /tmp/eee-lvds-temp | grep -F -e LVDS -A 12 | grep -F -e [0-9]x[0-9] -e "*" | awk '{print $1}')

function toggle_resolution {
  for mode in $LVDS_MODES $LVDS_MODES; do
    if [ "$mode" = "$LVDS_CURRENT" ]; then
      NEXT=1;
    elif [ "$NEXT" = "1" ]; then
      xrandr -s $mode
      eeepc_notify "LVDS Resolution: \"$mode\""
      echo $mode > $EEEPC_VAR/resolution_saved
      exit
    fi
  done
  rm /tmp/eeepc-lvds-temp 2>/dev/null
}

function restore_resolution {
  if [ -e "$EEEPC_VAR/resolution_saved" ]; then
    RESOLUTION=$(cat $EEEPC_VAR/resolution_saved)
    xrandr -s $RESOLUTION
    eeepc_notify "LVDS Resolution: \"$RESOLUTION\""
  fi
}

case $1 in
  restore)
    restore_resolution
  ;;
  *)
    toggle_resolution
  ;;
esac
