#!/bin/bash
#
# EeePC VGA toggle
# Andrew Wyatt
# Tool to enable / disable VGA output

. /etc/default/eeepc-acpi

function eeepc_notify {
/usr/bin/notify-send -i display -t 1500 "EeePC $EEEPC_MODEL" "$1"
}

if [ -e "/tmp/eee-vga-temp" ]; then
  rm -f /tmp/eee-vga-temp 2>/dev/null
fi

if [ ! -d "$EEEPC_VAR" ]; then
  mkdir $EEEPC_VAR 2>/dev/null
fi

if [ -e "$EEEPC_VAR/vga_saved" ]; then
  VGA_RESTORE=$(cat $EEEPC_VAR/vga_saved)
fi

VGA_XRANDR=$(xrandr > /tmp/eee-vga-temp)
VGA_STATUS=$(cat /tmp/eee-vga-temp | grep 'VGA connected' >/dev/null 2>&1 && echo connected)
VGA_ENABLED=$(cat /tmp/eee-vga-temp | grep 'VGA connected' -A 1 | grep "*" >/dev/null 2>&1 && echo 1)

function vga_toggle {
  if [ "$VGA_STATUS" = "connected" ]; then
    if [ "$VGA_ENABLED" = "1" ]; then
      ((xrandr --output VGA --off && eeepc_notify "VGA Disabled") || eeepc_notify "Could not disable VGA OUT")
      echo 0 > $EEEPC_VAR/vga_saved
    else
      ((xrandr --output VGA --auto && eeepc_notify "VGA Enabled") || eeepc_notify "Could not enable VGA OUT")
      echo 1 > $EEEPC_VAR/vga_saved
    fi
  else
    eeepc_notify "VGA Monitor not found."
  fi
}

function vga_restore {
   if [ "$VGA_RESTORE" = "1" ]; then
     xrandr --output VGA --auto
   elif [ "$VGA_RESTORE" = "0" ]; then
     xrandr --output VGA --off
   fi
}
rm /tmp/eee-vga-temp 2>/dev/null

case $1 in
  restore)
    vga_restore
  ;;
  *)
    vga_toggle
  ;;
esac
