#!/bin/bash
#
#  EeePC WIFI Toggle
#  by Andrew Wyatt
#  Generic WIFI toggle utility which should work across EeePC models.
#

. /etc/default/eeepc-acpi

if [ -e $EEEPC_VAR/eeepc-wifi-saved ]; then
  RADIO_SAVED_STATE=$(cat $EEEPC_VAR/eeepc-wifi-saved)
else
  RADIO_SAVED_STATE=0
fi

RADIO_CONTROL='/sys/class/rfkill/rfkill0/state'
if [ -e "$RADIO_CONTROL" ]; then
  RADIO_STATE=$(cat $RADIO_CONTROL);
fi

if [ ! -d "$EEEPC_VAR" ]; then
  mkdir $EEEPC_VAR 2>/dev/null
fi

WIFI_DRIVER=`lspci -k | grep -e ath5k -e rtl8187 -e ath9k -e rt2860sta | awk '{print $3}' | tail -n 1 `
if [ "$EEEPC_NDISWRAPPER" = "1" ]; then
  WIFI_DRIVER="ndiswrapper"
fi

function eeepc_notify {
/usr/bin/notify-send -i gnome-dev-wavelan -t 1500 "EeePC $EEEPC_MODEL" "$1"
}

WIFI_IF=$(iwconfig 2>/dev/null | grep ESSID | awk '{print $1}')

function radio_on {
echo 1 > $RADIO_CONTROL
(/sbin/modprobe $WIFI_DRIVER 2>/dev/null && (
  echo 1 > $EEEPC_VAR/eeepc-wifi-saved
  eeepc_notify "WIFI Radio on"  ) || eeepc_notify "Could not enable WIFI radio.")
}

function radio_off {
/sbin/ifconfig $WIFI_IF down 2>/dev/null
( /sbin/modprobe -r $WIFI_DRIVER 2>/dev/null && (
  sleep 1
  echo 0 > $RADIO_CONTROL
  echo 0 > $EEEPC_VAR/eeepc-wifi-saved
  eeepc_notify "WIFI Radio off" ) || eeepc_notify "Could not disable WIFI radio.") 
}

function radio_toggle {
  if [ "$RADIO_STATE" = "1" ]; then
    radio_off
  else
    radio_on
  fi
}

function radio_restore {
  if [ "$RADIO_SAVED_STATE" = "1" ]; then
    radio_on
  else
    radio_off
  fi
}

case $1 in
  "restore")
    radio_restore
  ;;
  *)
    radio_toggle
  ;;
esac
